@@ -13,13 +13,14 @@ import (
 	"strings"
 
 	"github.com/prometheus/client_golang/prometheus"
+	"github.com/prometheus/client_golang/prometheus/collectors"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
 	"k8s.io/klog/v2"
 
 	_ "k8s.io/client-go/plugin/pkg/client/auth"
 
-	ocollectors "github.com/stolostron/insights-metrics/pkg/collectors"
-	"github.com/stolostron/insights-metrics/pkg/options"
+	ocollectors "github.com/open-cluster-management/insights-metrics/pkg/collectors"
+	"github.com/open-cluster-management/insights-metrics/pkg/options"
 	metricsstore "k8s.io/kube-state-metrics/pkg/metrics_store"
 	koptions "k8s.io/kube-state-metrics/pkg/options"
 	"k8s.io/kube-state-metrics/pkg/whiteblacklist"
@@ -84,10 +85,10 @@ func main() {
 	if err := ocmMetricsRegistry.Register(ocollectors.ScrapeErrorTotalMetric); err != nil {
 		panic(err)
 	}
-	if err := ocmMetricsRegistry.Register(prometheus.NewProcessCollector(prometheus.ProcessCollectorOpts{})); err != nil {
+	if err := ocmMetricsRegistry.Register(collectors.NewProcessCollector(collectors.ProcessCollectorOpts{})); err != nil {
 		panic(err)
 	}
-	if err := ocmMetricsRegistry.Register(prometheus.NewGoCollector()); err != nil {
+	if err := ocmMetricsRegistry.Register(collectors.NewGoCollector()); err != nil {
 		panic(err)
 	}
 	go telemetryServer(ocmMetricsRegistry, opts.TelemetryHost, opts.TelemetryPort, opts.TLSCrtFile, opts.TLSKeyFile)
